==============================================
Welcome to the documentation of compute_hyperv
==============================================

Starting with Folsom, Hyper-V can be used as a compute node within OpenStack
deployments.

This documentation contains information on how to setup and configure Hyper-V
hosts as OpenStack compute nodes, more specifically:

* Supported OS versions
* Requirements and host configurations
* How to install the necessary OpenStack services
* ``nova-compute`` configuration options
* Troubleshooting and debugging tips & tricks

For release notes, please check out the following `page`__.

__ http://compute-hyperv.readthedocs.io/projects/releasenotes

Contents:

.. toctree::
   :maxdepth: 2

   readme
   contributing
   install/index
   troubleshooting/index
   configuration/index
   usage/index

* :ref:`search`
